@@ -2,7 +2,7 @@ package Test2::Tools::Compare;
 use strict;
 use warnings;
 
-our $VERSION = '0.000048';
+our $VERSION = '0.000050';
 
 use Carp qw/croak/;
 use Scalar::Util qw/reftype/;
@@ -65,7 +65,7 @@ our @EXPORT_OK = qw{
     in_set not_in_set check_set
     item field call call_list call_hash prop check all_items all_keys all_vals all_values
     end filter_items
-    T F D DF DNE FDNE E
+    T F D DF DNE FDNE E U
     event fail_events
     exact_ref
 };
@@ -146,6 +146,15 @@ sub bag(&)    { build('Test2::Compare::Bag',           @_) }
 sub object(&) { build('Test2::Compare::Object',        @_) }
 sub subset(&) { build('Test2::Compare::OrderedSubset', @_) }
 
+sub U() {
+    my @caller = caller;
+    Test2::Compare::Custom->new(
+        code => sub { defined $_ ? 0 : 1 }, name => 'UNDEFINED', operator => '!DEFINED()',
+        file => $caller[1],
+        lines => [$caller[2]],
+    );
+}
+
 sub D() {
     my @caller = caller;
     Test2::Compare::Custom->new(
@@ -797,6 +806,18 @@ This will fail:
 
     is(undef, D(), 'foo is defined');
 
+=item $check = U()
+
+This is to verify that the value in the C<$got> structure is undefined.
+
+This will pass:
+
+    is(undef, U(), 'not defined');
+
+This will fail:
+
+    is('foo', U(), 'not defined');
+
 =item $check = DF()
 
 This is to verify that the value in the C<$got> structure is defined but false.
@@ -975,7 +996,7 @@ block, and can call it any number of times with any number of arguments.
 
 =item all_values($CHECK1, $CHECK2, ...)
 
-Add checks that apply to all keys. You can put this anywhere in the hash
+Add checks that apply to all values. You can put this anywhere in the hash
 block, and can call it any number of times with any number of arguments.
 
 =item end()
